/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#include "GlobalPlan.h"

using namespace xmltio;
using namespace airobots;
using namespace std;

std::string GlobalPlan::getBaseTag() {
	return "GLOBALPLAN";
}

std::string GlobalPlan::getTemplate() {
	return "<" + getBaseTag() + "><GENERATOR/>" + Timestamp::getTemplate()
			+ "</" + getBaseTag() + ">";
}

GlobalPlan::GlobalPlan() : Type("unknown") {
}

GlobalPlan::GlobalPlan(std::string generator) :
	Type(generator) {

}

void GlobalPlan::addWaypoint(const NavigationGoalData waypoint) {
	waypoints.push_back(waypoint);
}

void GlobalPlan::removeLastWayoint() {
	waypoints.erase(--(waypoints.end()));
}

std::list<NavigationGoalData>::const_iterator GlobalPlan::begin() const {
	return waypoints.begin();
}

std::list<NavigationGoalData>::const_iterator GlobalPlan::end() const {
	return waypoints.end();
}

void GlobalPlan::clear() {
	waypoints.clear();
}

size_t GlobalPlan::size() const {
	return waypoints.size();
}

bool GlobalPlan::empty() const {
	return waypoints.empty();
}

void GlobalPlan::sanitizeLocation(xmltio::Location &loc) const {

	XPath xp(NavigationGoalData::getBaseTag());
	while (XPathIterator i = xp.evaluate(loc)) {
		Location l(*i);
		loc.remove(l);
	}

}

void GlobalPlan::fillInto(xmltio::Location &loc) const {

	Type::fillInto(loc);

	for (list<NavigationGoalData>::const_iterator it = begin(); it
			!= end(); it++) {

		Location newWaypoint(NavigationGoalData::getTemplate(),
				NavigationGoalData::getBaseTag());
		newWaypoint = *it;

		loc.add(newWaypoint);

	}

}

void GlobalPlan::fromLocation(const xmltio::Location &loc_, GlobalPlan &plan) {

	Type::fromLocation(loc_, plan);

	for (XPathIterator wpIter =
			XPath(NavigationGoalData::getBaseTag()).evaluate(loc_); wpIter; ++wpIter) {

		NavigationGoalData wp = extract<NavigationGoalData> (*wpIter);
		plan.addWaypoint(wp);

	}

}
