/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#ifndef OBJECTDATA_H_
#define OBJECTDATA_H_

#include <string>
#include <vector>
#include <list>

#include <xmltio/xmltio.hpp>

#include <boost/smart_ptr.hpp>

#include "Type.h"

namespace airobots {

/**
 * Results of the object recognition. This is a very general base class.
 *
 * @author lziegler
 */
class ObjectData: public Type {

public:

	class Hypothesis: public Type {
	private:
		/**
		 * Reliability of the recognition result.
		 */
		double reliability;

	public:

		static std::string getBaseTag();

		static std::string getTemplate();

		Hypothesis();
		Hypothesis(std::string generator);
		Hypothesis(const Hypothesis &h);

		double getReliability() const;
		void setReliability(const double &reliability);

		virtual bool operator==(const Hypothesis &other) const;

		void sanitizeLocation(xmltio::Location&) const;
		void fillInto(xmltio::Location &loc) const;
		static void fromLocation(const xmltio::Location &loc, Hypothesis &type);

	};

	static std::string getBaseTag();

	static std::string getTemplate();

	ObjectData();
	ObjectData(std::string generator);
	~ObjectData();

	std::string getClassLabel() const;
	void setClassLabel(const std::string &label);

	void addHypothesis(Hypothesis &h);
	void clearHypotheses();
	std::vector<Hypothesis> getHypotheses() const;

	virtual bool operator==(const ObjectData &other) const;

	void sanitizeLocation(xmltio::Location&) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, ObjectData &type);

private:

	/**
	 * Name of this object.
	 */
	std::string classLabel;

protected:
	std::vector<boost::shared_ptr<Hypothesis> > hypotheses;

};

}

#endif /* OBJECTDATA_H_ */
