/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * PositionData.cpp
 *
 *  Created on: Jul 31, 2009
 *      Author: jwienke
 */

#include "PositionData.h"

using namespace std;
using namespace airobots;
using namespace xmltio;

namespace airobots {

std::string PositionData::getBaseTag() {
	return "ROBOTPOSITION";
}

std::string PositionData::getTemplate() {

	return "<" + getBaseTag() + ">"
		+ "<GENERATOR/>"
		+ airobots::Timestamp::getTemplate()
		+ "<POSITION ref=\"world\" kind=\"absolute\" x=\"\" y=\"\" theta=\"\" />"
		+ "</" + getBaseTag() + ">";

}

PositionData::PositionData() :
	x(0), y(0), theta(0) {

}

PositionData::PositionData(float x, float y, float theta) :
	x(x), y(y), theta(theta) {

}

PositionData::~PositionData() {
}

float PositionData::getX() const {
	return x;
}

void PositionData::setX(float x) {
	this->x = x;
}

float PositionData::getY() const {
	return y;
}

void PositionData::setY(float y) {
	this->y = y;
}

float PositionData::getTheta() const {
	return theta;
}

void PositionData::setTheta(float theta) {
	this->theta = theta;
}

void PositionData::sanitizeLocation(xmltio::Location &loc) const {

}

void PositionData::fillInto(xmltio::Location &loc) const {

	Type::fillInto(loc);

	loc[XPath("POSITION/@x")] = getX();
	loc[XPath("POSITION/@y")] = getY();
	loc[XPath("POSITION/@theta")] = getTheta();

}

void PositionData::fromLocation(const xmltio::Location &loc_, PositionData &pos) {

	Type::fromLocation(loc_, pos);

	pos.setX(extract<float> (loc_[XPath("POSITION/@x")]));
	pos.setY(extract<float> (loc_[XPath("POSITION/@y")]));
	pos.setTheta(extract<float> (loc_[XPath("POSITION/@theta")]));

}

}
