/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * SonarData.cpp
 *
 *  Created on: Nov 4, 2010
 *      Author: ltwardon
 */

#include "SonarData.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

std::string SonarData::getBaseTag()
{
	return "SONARDATA";
}

std::string SonarData::getTemplate()
{
	return std::string("<") + getBaseTag() + "><GENERATOR/>"
			+ Timestamp::getTemplate() + "<DISTLEFT value=\"\" />"
			+ "<DISTRIGHT value=\"\" />"
			+ "</" + getBaseTag() + ">";
}

SonarData::SonarData() :
	Type("unknown")
{

}

SonarData::SonarData(double distanceRight, double distanceLeft) :
	distanceRight(distanceRight), distanceLeft(distanceLeft)
{

}

double SonarData::getDistanceRight() const
{
	return distanceRight;
}
void SonarData::setDistanceRight(double distanceRight)
{
	this->distanceRight = distanceRight;
}

double SonarData::getDistanceLeft() const
{
	return distanceLeft;
}
void SonarData::setDistanceLeft(double distanceLeft)
{
	this->distanceLeft = distanceLeft;
}

void SonarData::sanitizeLocation(xmltio::Location &loc) const
{

}

void SonarData::fillInto(xmltio::Location &loc) const
{

	Type::fillInto(loc);

	loc[XPath("DISTLEFT/@value")] = getDistanceLeft();
	loc[XPath("DISTRIGHT/@value")] = getDistanceRight();

}

void SonarData::fromLocation(const xmltio::Location &loc_, SonarData &sd)
{

	Type::fromLocation(loc_, sd);

	sd.setDistanceLeft(extract<double> (loc_[XPath("DISTLEFT/@value")]));
	sd.setDistanceRight(extract<double> (loc_[XPath("DISTRIGHT/@value")]));

}

