/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/** ==========================================================================
 * 
 * @file		SplocAngleData.h --
 * @brief		Header file for the angle output of the sploc application.
 *
 * @author	Denis Schulze <dschulze@techfak.uni-bielefeld.de>
 * 
 * ========================================================================== 
 **/

#ifndef SPLOCANGLEDATA_H_
#define SPLOCANGLEDATA_H_

#include <vector>

#include "Type.h"
#include "Ticked.h"

namespace airobots {

/**
 * BTL type for work with the output from the sploc ES speaker localization
 * application.
 */
class SplocAngleData: public Type, public Ticked {

public:

	/** Constructor. */
	SplocAngleData();

	/** Deconstructor. */
	~SplocAngleData();

	static std::string getBaseTag();

	static std::string getTemplate();

	/** Returns all angles to sound percepts. */
	std::vector<float> getAngles();

	/** Sets new angles to sound percepts. */
	void setAngles(std::vector<float> angles);

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, SplocAngleData &list);

private:
	/** A list of all computed angles from the sploc application. */
	std::vector<float> angles;

};

}

#endif /** SPLOCANGLEDATA_H_ */
