/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data;

import nu.xom.Attribute;
import nu.xom.Element;
import nu.xom.Node;
import nu.xom.Nodes;
import de.unibi.airobots.btl.common.ElementParser;

public class Voice extends Type implements Percept {

	@Override
	public String getPerceptName() {
		return "voice";
	}

	public static String getBaseTag() {
		return "VOICE";
	}

	public static void fromElement(Element element, Voice type) {

		Type.fromElement(element, type);

		Nodes nodes = element.query("*");
		for (int i = 0; i < nodes.size(); i++) {
			Node node = nodes.get(i);
			if (node instanceof Element) {
				Element elem = (Element) node;
				if (elem.getLocalName().equals("POSITION")) {
					type.setAngle((float) ElementParser
							.getDoubleAttributeValue(elem, "angle"));
					type.setAngleVariance((float) ElementParser
							.getDoubleAttributeValue(elem, "angleVariance"));
					type.setRuntimeDifference((float) ElementParser
							.getDoubleAttributeValue(elem, "runtimeDifference"));
					type.setRuntimeDifferenceVariance((float) ElementParser
							.getDoubleAttributeValue(elem,
									"runtimeDifferenceVariance"));
				}
			}
		}

	}

	public void fillInto(Element parent) {

		super.fillInto(parent);

		Element posElement = new Element("POSITION");
		parent.appendChild(posElement);
		posElement.addAttribute(new Attribute("" + "angle", String
				.valueOf(getAngle())));
		posElement.addAttribute(new Attribute("" + "angleVariance", String
				.valueOf(getAngleVariance())));
		posElement.addAttribute(new Attribute("" + "runtimeDifference", String
				.valueOf(getRuntimeDifference())));
		posElement.addAttribute(new Attribute("" + "runtimeDifferenceVariance",
				String.valueOf(getRuntimeDifferenceVariance())));

	}

	public void setAngle(float angle) {
		this.angle = angle;
	}

	public float getAngle() {
		return angle;
	}

	public void setRuntimeDifference(float runtimeDifference) {
		this.runtimeDifference = runtimeDifference;
	}

	public float getRuntimeDifference() {
		return runtimeDifference;
	}

	public void setAngleVariance(float angleVariance) {
		this.angleVariance = angleVariance;
	}

	public float getAngleVariance() {
		return angleVariance;
	}

	public void setRuntimeDifferenceVariance(float runtimeDifferenceVariance) {
		this.runtimeDifferenceVariance = runtimeDifferenceVariance;
	}

	public float getRuntimeDifferenceVariance() {
		return runtimeDifferenceVariance;
	}

	public boolean equals(Voice other) {
		return (super.equals(other))
				&& (this.getAngle() == other.getAngle())
				&& (this.getAngleVariance() == other.getAngleVariance())
				&& (this.getRuntimeDifference() == other.getRuntimeDifference())
				&& (this.getRuntimeDifferenceVariance() == other
						.getRuntimeDifferenceVariance());
	}

	private float angle;
	private float runtimeDifference;
	private float angleVariance;
	private float runtimeDifferenceVariance;

}
