/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data;

import static org.junit.Assert.*;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.common.Timestamp;

/**
 * Test cases for {@link Type}.
 * 
 * @author ltwardon
 */
public class ShirtTest {
	
	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() throws Exception {
		
		try{
		
			Shirt original = new Shirt();
			original.setGenerator("test");
			final long timestamp = System.currentTimeMillis();
			original.setTimestamp(timestamp);
			original.setAngle(0.45f);
			original.setDistance(77.23f);
			original.setAngleVariance(0.345f);
			original.setDistanceVariance(1.34f);
	
			Document doc = new Document(
					new Element(Shirt.getBaseTag()));
			original.fillInto(doc.getRootElement());
			logger.info(doc.toXML());
			
			Shirt parsed = new Shirt();
			Shirt.fromElement(doc.getRootElement(), parsed);
			
			assertEquals(parsed.getGenerator(), original.getGenerator());
			assertEquals(parsed.getTimestamp(), original.getTimestamp());
			assertEquals(parsed.getAngle(), original.getAngle(), 0.0001);
			assertEquals(parsed.getDistance(), original.getDistance(), 0.0001);
			assertEquals(parsed.getAngleVariance(), original.getAngleVariance(), 0.0001);
			assertEquals(parsed.getDistanceVariance(), original.getDistanceVariance(), 0.0001);
		
		} catch(Exception e) {
			fail("Caught exception" + e.getMessage());
		}
			
	}
	
	@Test
	public void fileCompatibility() throws Exception {
		
		Builder parser = new Builder();
		Document doc = parser.build(TestUtils
				.makeTestFileName("Shirt.xml"));

		Shirt parsed = new Shirt();
		Shirt.fromElement(doc.getRootElement(), parsed);
		assertEquals(doc.getRootElement().getLocalName(), Shirt
				.getBaseTag());

		assertEquals("test", parsed.getGenerator());
		assertEquals(new Timestamp(12345, 67890), parsed.getTimestamp());
		assertEquals(0.45, parsed.getAngle(), 0.0001);
		assertEquals(77.23, parsed.getDistance(), 0.0001);
		assertEquals(0.345, parsed.getAngleVariance(), 0.0001);
		assertEquals(1.34, parsed.getDistanceVariance(), 0.0001);
		
	}

}